#ifndef Application_h
#define Application_h

// $Id: Application.h,v 1.13 2012/02/21 12:01:43 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "BaseApplication.h"
#include "Config.h"
#include "CommandLineArguments.h"
#include "CommandLineParser.h"
#include "Counter.h"
#include "TaskBarBase.h"
#include "TaskBarAttributes.h"

//! Main Window singleton object
class Application: public BaseApplication, public Counter
{

  //! Qt meta object declaration
  Q_OBJECT

  public:

  //! command line help
  static void usage( void );

  //! constructor
  Application( CommandLineArguments );

  #if defined(Q_WS_X11)
  //! constructor
  Application( Display*, int argc, char*argv[], Qt::HANDLE, Qt::HANDLE );
  #endif

  //! destructor
  ~Application( void );

  //! create all widgets
  bool realizeWidget( void );

  //! number of bars
  unsigned int numberOfTaskbars( void ) const
  { return taskbars_.size(); }

  //! current taskbar
  TaskBarBase* currentTaskBar( void ) const
  { return _taskBar( _currentAttributes() ); }

  //!@name actions
  //@{

  //! add taskbar
  QAction& addTaskBarAction( void ) const
  { return *add_taskbar_action_; }

  //! remove taskbar
  QAction& removeTaskBarAction( void ) const
  { return *remove_taskbar_action_; }

  //@}

  protected slots:

  //! configuration
  virtual void _configuration( void );

  //! about
  virtual void _about( void )
  { BaseApplication::_about( MAIN_TITLE, VERSION, BUILD_TIMESTAMP ); }

  //! add taskbar
  void _addTaskBar( void );

  //! modify task bar attributes
  void _editTaskBar( const TaskBarAttributes& );

  //! remove taskbar
  void _removeTaskBar( const bool& ask = true );

  //! save taskbars
  void _readTaskBars( void );

  //! save taskbars
  void _writeTaskBars(  bool check = true ) const;

  //! actions called when application is about to quit
  void _aboutToQuit( void );

  //! current taskbar attributes
  void _setCurrentAttributes( const TaskBarAttributes& attributes )
  {
    Debug::Throw( "Application::_setCurrentAttributes.\n" );
    current_attributes_ = attributes;
  }

  //! process request from application manager
  virtual bool _processCommand( SERVER::ServerCommand );

  private:

  //! create a new task bar from attributes
  TaskBarBase* _newTaskBar( const TaskBarAttributes& attributes = TaskBarAttributes() );

  //! get taskbar from attributes
  TaskBarBase* _taskBar( const TaskBarAttributes& attributes ) const;

  //! update actions
  void _updateActions( void ) const;

  //! current taskbar attributes
  const TaskBarAttributes& _currentAttributes( void ) const
  { return current_attributes_; }

  //! current taskbar attributes
  TaskBarAttributes& _currentAttributes( void )
  { return current_attributes_; }

  //! window flags
  static Qt::WFlags _flags( void );

  //! title
  QString MAIN_TITLE;

  //! taskbars
  TaskBarBase::List taskbars_;

  //! TaskBarAttributes for the selected taskbar
  TaskBarAttributes current_attributes_;

  //!@name actions
  //@{

  //! add taskbar
  QAction* add_taskbar_action_;

  //! remove taskbar
  QAction* remove_taskbar_action_;

  //@}

};

#endif

