// $Id: TaskAttributesModel.cpp,v 1.16 2012/02/20 20:49:49 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file    TaskAttributesModel.h
\brief   Job model. Stores job information for display in lists
\author  Hugo Pereira
\version $Revision: 1.16 $
\date    $Date: 2012/02/20 20:49:49 $
*/

#include "CustomPixmap.h"
#include "TaskAttributesModel.h"
#include "Icons.h"
#include "IconSize.h"
#include "TimeStamp.h"
#include "XmlOptions.h"

#include <QtGui/QIcon>

//_______________________________________________
const QString TaskAttributesModel::columnTitles_[ TaskAttributesModel::nColumns_ ] =
{
    "Icon",
    "Name",
    "Comments",
    "Command",
    "Argument"
};

//_______________________________________________________________
TaskAttributesModel::TaskAttributesModel( QObject* parent ):
    ListModel<TaskAttributes>( parent ),
    Counter( "TaskAttributesModel" )
{Debug::Throw( "TaskAttributesModel::TaskAttributesModel.\n" );}

//__________________________________________________________________
QVariant TaskAttributesModel::data( const QModelIndex& index, int role ) const
{
    Debug::Throw( "TaskAttributesModel::data.\n" );

    // check index, role and column
    if( !index.isValid() ) return QVariant();

    // retrieve associated file info
    const TaskAttributes& attributes( get()[index.row()] );

    // return text associated to file and column
    if( role == Qt::DisplayRole ) {

        switch( index.column() )
        {
            case NAME:
            return attributes.name();

            case COMMENTS:
            return attributes.comments();

            case COMMAND:
            return attributes.command();

            default:
            return QVariant();
        }
    }

    // return icon associated to file
    if( role == Qt::DecorationRole && index.column() == ICON && !attributes.flag( TaskAttributes::IS_SEPARATOR ) )
    { return _icon( attributes.iconName() ); }

    return QVariant();

}

//__________________________________________________________________
QVariant TaskAttributesModel::headerData(int section, Qt::Orientation orientation, int role) const
{

    if(
        orientation == Qt::Horizontal &&
        role == Qt::DisplayRole &&
        section >= 0 &&
        section < nColumns_ )
    { return columnTitles_[section]; }

    // return empty
    return QVariant();

}

//_______________________________________________
TaskAttributesModel::IconCache& TaskAttributesModel::_icons( void )
{
    static IconCache cache;
    return cache;
}


//_____________________________________________________________________
QIcon TaskAttributesModel::_icon( const QString& value )
{

    Debug::Throw( "CondorCommandList::_installIcons" );

    IconCache::iterator iter = _icons().find( value );
    if( iter != _icons().end() ) return iter.value();

    // load pixmaps
    QSize size( IconSize( IconSize::Large ) );
    QSize scale = 0.85*size;

    QIcon icon = CustomPixmap().empty( size )
        .merge( CustomPixmap( value )
        .scaled( scale, Qt::KeepAspectRatio, Qt::SmoothTransformation ),
        CustomPixmap::CENTER );

    _icons().insert( value, icon );
    return icon;

}
