// $Id: TaskToolTip.h,v 1.22 2012/05/04 09:10:38 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#ifndef TaskToolTip_h
#define TaskToolTip_h

/*!
\file    TaskToolTip.h
\brief   task information tooltip
\author  Hugo Pereira
\version $Revision: 1.22 $
\date    $Date: 2012/05/04 09:10:38 $
*/

#include "Counter.h"
#include "Debug.h"
#include "QtUtil.h"
#include "RoundedRegion.h"
#include "TaskAttributes.h"
#include "TransparentWidget.h"

#include <QtCore/QBasicTimer>
#include <QtGui/QPaintEvent>
#include <QtGui/QPixmap>
#include <QtCore/QTimerEvent>
#include <QtCore/QHash>

//! application splash screen
class TaskToolTip: public TRANSPARENCY::TransparentWidget
{

    //! qt meta object macros
    Q_OBJECT

    public:

    //! constructor
    TaskToolTip( QWidget* parent = 0, const TaskAttributes& attributes = TaskAttributes() );

    //! set task
    void setAttributes( const TaskAttributes& );

    //!@name flags
    //@{

    //! status in list
    enum Flag
    {
        NONE = 0,
        ROUNDED = 1<<0,
        VISIBLE = 1<<1
    };

    //! flags
    bool flag( const Flag& flag ) const
    { return flags_ & flag; }

    //! flags
    TaskToolTip& setFlag( const Flag& flag, const bool& value )
    {
        if( value ) flags_ |= flag;
        else flags_ &= (~flag);
        return *this;
    }

    //! flags
    const unsigned int& flags( void ) const
    { return flags_; }

    //@}

    //! adjusted size
    const QSize& adjustedSize( void ) const
    { return size_; }

    //! delay
    void setDelay( const unsigned int delay )
    { delay_ = delay; }

    //! show (with delay if hidden)
    void show( void );

    //! hide (with delay)
    void hide( bool now );

    //! stop timers
    void stopTimers( void );

    public slots:

    //! clear pixmap cache
    virtual void clearCache( void )
    { cache_.clear(); }

    protected:

    //! resize event [overloaded]
    virtual void resizeEvent( QResizeEvent* );

    //! paint event
    virtual void _paint( QPaintDevice&, const QRect& );

    //! timer event, to toggle repaint
    virtual void timerEvent( QTimerEvent* );

    protected slots:

    //! configuration
    virtual void _updateConfiguration( void );

    private:

    //!@name accessors
    //@{

    //! pixmaps
    QPixmap _pixmap( void ) const
    { return pixmap_; }

    //! pixmap
    void _setPixmap( QPixmap pixmap )
    { pixmap_ = pixmap; }

    //! title
    const QString& _title( void ) const
    { return title_; }

    //! title
    void _setTitle( const QString& title )
    { title_ = title; }

    //! comments
    const QString& _comments( void ) const
    { return comments_; }

    //! comments
    void _setComments( const QString& comments )
    { comments_ = comments; }

    //! compute size based on attributes contents
    void _adjustSize( void );

    //! show timer
    QBasicTimer& _showTimer( void )
    { return showTimer_; }

    //! hide timer
    QBasicTimer& _hideTimer( void )
    { return hideTimer_; }

    //@}

    //! use svg
    const bool& _useSvg( void ) const
    { return useSvg_; }

    //! use svg
    void _setUseSvg( const bool& value )
    { useSvg_ = value; }

    //! use style
    const bool& _useStyle( void ) const
    { return useStyle_; }

    //! use style
    void _setUseStyle( const bool& value )
    { useStyle_ = value; }

    //! pixmap
    QPixmap pixmap_;

    //! title
    QString title_;

    //! comments
    QString comments_;

    //! widget size
    QSize size_;

    //! fonts
    QFont largeFont_;

    //! fonts
    QFont normalFont_;

    //!@name timers
    //@{

    //! timer
    QBasicTimer showTimer_;

    //! tooltip hiding timer
    /*!
    it is used so that a tooltip is drawn immediately if
    the previous one is still "visible". Technically, it is
    hidden when the button is leaved, but the flag remains true
    for few milliseconds
    */
    QBasicTimer hideTimer_;

    //@}

    //! delay
    unsigned int delay_;

    //! flags
    unsigned int flags_;

    //! pixmap size
    QSize pixmapSize_;

    //! margin
    int margin_;

    //! use style for rendering tooltip
    bool useStyle_;

    //! use svg
    bool useSvg_;

    //! pixmap cache
    typedef QHash<QString, QPixmap> Cache;

    //! pixmap cache
    Cache cache_;

};

#endif
